==> libgrinvin-core-java_1.0.4.orig.tar.gz: grinvin-core-1.0.4/org/grinvin/util/IOHelper.java <==
/* IOHelper.java
 * =========================================================================
 * This file is part of the GrInvIn project - http://www.grinvin.org
 * 
 * Copyright (C) 2005-2007 Universiteit Gent
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * A copy of the GNU General Public License can be found in the file
 * LICENSE.txt provided with the source distribution of this program (see
 * the META-INF directory in the source jar). This license can also be
 * found on the GNU website at http://www.gnu.org/licenses/gpl.html.
 * 
 * If you did not receive a copy of the GNU General Public License along
 * with this program, contact the lead developer, or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

package org.grinvin.util;

import java.io.File;

/**
 * Class that contains some static helper methods.
 * //TODO: should be placed elsewhere
 */
public class IOHelper {
    
    /**
     * Delete a directory recursively.
     */
    public static boolean deleteDirectory(File directory) {
        // first delete all subdirectories
        if (directory.isDirectory()) {
            File[] children = directory.listFiles();
            for (File file : children) {
                boolean success = deleteDirectory(file);
                if (!success) {
                    return false;
                }
            }
        }
        // now we delete the main directory
        return directory.delete();
        
    }
}

==> libgrinvin-core-java_1.2.orig.tar.gz: grinvin-core-1.2/org/grinvin/util/IOHelper.java <==
/* IOHelper.java
 * =========================================================================
 * This file is part of the GrInvIn project - http://www.grinvin.org
 * 
 * Copyright (C) 2005-2008 Universiteit Gent
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * A copy of the GNU General Public License can be found in the file
 * LICENSE.txt provided with the source distribution of this program (see
 * the META-INF directory in the source jar). This license can also be
 * found on the GNU website at http://www.gnu.org/licenses/gpl.html.
 * 
 * If you did not receive a copy of the GNU General Public License along
 * with this program, contact the lead developer, or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

package org.grinvin.util;

import java.io.File;

/**
 * Class that contains some static helper methods.
 * //TODO: should be placed elsewhere
 */
public class IOHelper {
    
    /**
     * Delete a directory recursively.
     */
    public static boolean deleteDirectory(File directory) {
        // first delete all subdirectories
        if (directory.isDirectory()) {
            File[] children = directory.listFiles();
            for (File file : children) {
                boolean success = deleteDirectory(file);
                if (!success) {
                    return false;
                }
            }
        }
        // now we delete the main directory
        return directory.delete();
        
    }
    
    public static String uniqueFileName(String prefix, String suffix) {
        return prefix + System.currentTimeMillis() + suffix;
        
    }
}
